==> rustc_1.86.0+dfsg1.orig.tar.xz: rustc-1.86.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.14.0/src/stm32f427/can1/fb/fr2.rs <==
#[doc = "Register `FR2` reader"]
pub struct R(crate::R<FR2_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FR2_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FR2_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FR2_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FR2` writer"]
pub struct W(crate::W<FR2_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FR2_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FR2_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FR2_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `FB` reader - Filter bits"]
pub struct FB_R(crate::FieldReader<u32, u32>);
impl FB_R {
    pub(crate) fn new(bits: u32) -> Self {
        FB_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FB_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FB` writer - Filter bits"]
pub struct FB_W<'a> {
    w: &'a mut W,
}
impl<'a> FB_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Filter bits"]
    #[inline(always)]
    pub fn fb(&self) -> FB_R {
        FB_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Filter bits"]
    #[inline(always)]
    pub fn fb(&mut self) -> FB_W {
        FB_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Filter bank 0 register 2\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [fr2](index.html) module"]
pub struct FR2_SPEC;
impl crate::RegisterSpec for FR2_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [fr2::R](R) reader structure"]
impl crate::Readable for FR2_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [fr2::W](W) writer structure"]
impl crate::Writable for FR2_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FR2 to value 0"]
impl crate::Resettable for FR2_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> rustc_1.90.0+dfsg1.orig.tar.xz: rustc-1.90.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.15.1/src/stm32f427/can1/fb/fr2.rs <==
#[doc = "Register `FR2` reader"]
pub struct R(crate::R<FR2_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FR2_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FR2_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FR2_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FR2` writer"]
pub struct W(crate::W<FR2_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FR2_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FR2_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FR2_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `FB` reader - Filter bits"]
pub type FB_R = crate::FieldReader<u32, u32>;
#[doc = "Field `FB` writer - Filter bits"]
pub type FB_W<'a, const O: u8> = crate::FieldWriter<'a, u32, FR2_SPEC, u32, u32, 32, O>;
impl R {
    #[doc = "Bits 0:31 - Filter bits"]
    #[inline(always)]
    pub fn fb(&self) -> FB_R {
        FB_R::new(self.bits)
    }
}
impl W {
    #[doc = "Bits 0:31 - Filter bits"]
    #[inline(always)]
    pub fn fb(&mut self) -> FB_W<0> {
        FB_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Filter bank 0 register 2\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [fr2](index.html) module"]
pub struct FR2_SPEC;
impl crate::RegisterSpec for FR2_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [fr2::R](R) reader structure"]
impl crate::Readable for FR2_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [fr2::W](W) writer structure"]
impl crate::Writable for FR2_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FR2 to value 0"]
impl crate::Resettable for FR2_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
